;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "perspective" "20251104.1408"
  "Switch between named \"perspectives\" of the editor."
  '((emacs  "24.4")
    (cl-lib "0.5"))
  :url "http://github.com/nex3/perspective-el"
  :commit "7f47c9a7be7b7d03f6d8430c84eec80ae5896699"
  :revdesc "7f47c9a7be7b"
  :keywords '("workspace" "convenience" "frames")
  :authors '(("Natalie Weizenbaum" . "nex342@gmail.com"))
  :maintainers '(("Natalie Weizenbaum" . "nex342@gmail.com")))
